@@ -1,6 +1,7 @@
 import bionetgen as bng
 from bionetgen.core import BNGResult
 from bionetgen.core import BNGPlotter
+from bionetgen.core import BNGInfo
 from bionetgen.modelapi.utils import run_command
 import bionetgen.modelapi.model as mdl
 
@@ -69,6 +70,22 @@ def plotDAT(inp, out=".", kw=dict()):
     plotter.plot()
 
 
+def printInfo(config, args):
+    """
+    ___
+    """
+    # this pulls out the arguments
+    # inp_file = args.input
+    # output = args.output
+    # if you set args.bngpath it should take precedence
+    # config_bngpath = config.get("bionetgen", "bngpath")
+    # and instantiates the CLI object
+    info = BNGInfo(config=config)
+    info.gatherInfo()
+    info.messageGeneration()
+    info.run()
+
+
 class BNGCLI:
     """
     Command Line Interface class to run BNG2.pl on a given
